from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckCategories, CheckResult


class AppServiceDetailedErrorMessagesEnabled(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure that App service enables detailed error messages"
        id = "CKV_AZURE_65"
        supported_resources = ('azurerm_app_service', 'azurerm_linux_web_app', 'azurerm_windows_web_app')
        categories = (CheckCategories.LOGGING,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources,
                         missing_block_result=CheckResult.FAILED)

    def get_inspected_key(self):
        if self.entity_type == 'azurerm_app_service':
            return "logs/[0]/detailed_error_messages_enabled"
        else:
            return "logs/[0]/detailed_error_messages"


check = AppServiceDetailedErrorMessagesEnabled()



from typing import Dict, List, Any

from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class ECSContainerHostProcess(BaseResourceCheck):
    def __init__(self) -> None:
        """
        NIST.800-53.r5 CA-9(1), NIST.800-53.r5 CM-2
        ECS task definitions should not share the host's process namespace
        """
        name = "Ensure ECS task definitions should not share the host's process namespace"
        id = "CKV_AWS_335"
        supported_resources = ("aws_ecs_task_definition",)
        categories = (CheckCategories.GENERAL_SECURITY,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf: Dict[str, List[Any]]) -> CheckResult:
        self.evaluated_keys = ["container_definitions"]
        container_definitions = conf.get("container_definitions")
        if container_definitions and isinstance(container_definitions, list):
            containers = container_definitions[0]
            if containers and isinstance(containers, list):
                for idx, container in enumerate(containers):
                    if isinstance(container, dict) and container.get("pidMode") == "host":
                        self.evaluated_keys = [f"container_definitions/[{idx}]/pidMode"]
                        return CheckResult.FAILED
                return CheckResult.PASSED
            elif isinstance(containers, dict):
                # TF plan file case
                for idx, container in enumerate(container_definitions):
                    if isinstance(container, dict) and container.get("pidMode") == "host":
                        self.evaluated_keys = [f"container_definitions/[{idx}]/pidMode"]
                        return CheckResult.FAILED
                return CheckResult.PASSED

        return CheckResult.UNKNOWN


check = ECSContainerHostProcess()



from typing import Any, Dict

from checkov.common.models.enums import CheckResult
from checkov.kubernetes.checks.resource.base_container_check import BaseK8sContainerCheck


class CPURequests(BaseK8sContainerCheck):
    def __init__(self) -> None:
        name = "CPU requests should be set"
        id = "CKV_K8S_10"
        # Location: container .resources.requests.cpu
        super().__init__(name=name, id=id)

    def scan_container_conf(self, metadata: Dict[str, Any], conf: Dict[str, Any]) -> CheckResult:
        self.evaluated_container_keys = ["resources/requests/cpu"]
        res = conf.get("resources")
        if res:
            if not isinstance(res, dict):
                return CheckResult.UNKNOWN
            requests = res.get("requests")
            if not isinstance(requests, dict):
                return CheckResult.UNKNOWN
            if requests and requests.get("cpu"):  # nosec  # false positive
                return CheckResult.PASSED
        return CheckResult.FAILED


check = CPURequests()



from cdk_integration_tests.utils import run_check


def test_CKV_AWS_18_S3BucketLogging():
    run_check(lang='python', check_name="S3BucketLogging")


def test_CKV_AWS_19_S3BucketEncryption():
    run_check(lang='python', check_name="S3BucketEncryption")


def test_CKV_AWS_21_S3BucketVersioning():
    run_check(lang='python', check_name="S3BucketVersioning")


def test_CKV_AWS_145_S3BucketKMSEncryption():
    run_check(lang='python', check_name="S3BucketKMSEncryption")


def test_CKV2_AWS_6_S3BucketPublicAccessBlock():
    run_check(lang='python', check_name="S3BucketPublicAccessBlock")


def test_CKV_AWS_54_S3BlockPublicPolicy():
    run_check(lang='python', check_name="S3BlockPublicPolicy")


def test_CKV_AWS_26_SNSTopicEncryption():
    run_check(lang='python', check_name="SNSTopicEncryption")


def test_CKV_AWS_20_S3PublicACLRead():
    run_check(lang='python', check_name="S3PublicACLRead")


def test_CKV_AWS_55_S3IgnorePublicACLs():
    run_check(lang='python', check_name="S3IgnorePublicACLs")


def test_CKV_AWS_56_S3RestrictPublicBuckets():
    run_check(lang='python', check_name="S3RestrictPublicBuckets")


def test_CKV_AWS_53_S3BlockPublicACLs():
    run_check(lang='python', check_name="S3BlockPublicACLs")


def test_CKV_AWS_57_S3PublicACLWrite():
    run_check(lang='python', check_name="S3PublicACLWrite")


def test_CKV_AWS_115_LambdaFunctionLevelConcurrentExecutionLimit():
    run_check(lang='python', check_name="LambdaFunctionLevelConcurrentExecutionLimit")


def test_CKV_AWS_116_LambdaDLQConfigured():
    run_check(lang='python', check_name="LambdaDLQConfigured")


def test_CKV_AWS_28_DynamodbRecovery():
    run_check(lang='python', check_name="DynamodbRecovery")


def test_CKV_AWS_158_CloudWatchLogGroupKMSKey():
    run_check(lang='python', check_name="CloudWatchLogGroupKMSKey")


def test_CKV_AWS_3_EBSEncryption():
    run_check(lang='python', check_name="EBSEncryption")


def test_CKV_AWS_120_APIGatewayCacheEnable():
    run_check(lang='python', check_name="APIGatewayCacheEnable")


def test_CKV_AWS_163_ECRImageScanning():
    run_check(lang='python', check_name="ECRImageScanning")


def test_CKV_AWS_51_ECRImmutableTags():
    run_check(lang='python', check_name="ECRImmutableTags")


def test_CKV_AWS_44_NeptuneClusterStorageEncrypted():
    run_check(lang='python', check_name="NeptuneClusterStorageEncrypted")


def test_CKV_AWS_166_BackupVaultEncrypted():
    run_check(lang='python', check_name="BackupVaultEncrypted")


def test_CKV_AWS_74_DocDBEncryption():
    run_check(lang='python', check_name="DocDBEncryption")


def test_CKV_AWS_47_DAXEncryption():
    run_check(lang='python', check_name="DAXEncryption")


def test_CKV_AWS_156_WorkspaceRootVolumeEncrypted():
    run_check(lang='python', check_name="WorkspaceRootVolumeEncrypted")


def test_CKV_AWS_155_WorkspaceUserVolumeEncrypted():
    run_check(lang='python', check_name="WorkspaceUserVolumeEncrypted")


def test_CKV_AWS_165_DynamodbGlobalTableRecovery():
    run_check(lang='python', check_name="DynamodbGlobalTableRecovery")


def test_CKV_AWS_27_SQSQueueEncryption():
    run_check(lang='python', check_name="SQSQueueEncryption")


def test_CKV_AWS_195_GlueSecurityConfigurationEnabled():
    run_check(lang='python', check_name="GlueSecurityConfigurationEnabled")


def test_CKV_AWS_30_ElasticacheReplicationGroupEncryptionAtTransit():
    run_check(lang='python', check_name="ElasticacheReplicationGroupEncryptionAtTransit")


def test_CKV_AWS_68_WAFEnabled():
    run_check(lang='python', check_name="WAFEnabled")


def test_CKV_AWS_64_RedshiftClusterEncryption():
    run_check(lang='python', check_name="RedshiftClusterEncryption")



from checkov.common.models.enums import CheckCategories
from checkov.cloudformation.checks.resource.base_resource_value_check import BaseResourceValueCheck


class WorkspaceRootVolumeEncrypted(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure that Workspace root volumes are encrypted"
        id = "CKV_AWS_156"
        supported_resources = ['AWS::WorkSpaces::Workspace']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return 'Properties/RootVolumeEncryptionEnabled'


check = WorkspaceRootVolumeEncrypted()
